#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name woodstox
%global core_name %{base_name}-core
Name:           %{core_name}
Version:        6.2.8
Release:        150200.3.4.3
Summary:        XML processor
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/FasterXML/woodstox
Source0:        https://github.com/FasterXML/%{base_name}/archive/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(com.fasterxml:oss-parent:pom:)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(net.java.dev.msv:msv-core)
BuildRequires:  mvn(net.java.dev.msv:xsdlib)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-shade-plugin)
BuildRequires:  mvn(org.codehaus.woodstox:stax2-api)
BuildRequires:  mvn(org.osgi:osgi.core)
BuildRequires:  mvn(relaxngDatatype:relaxngDatatype)
BuildArch:      noarch

%description
Woodstox is a validating namespace-aware StAX-compliant (JSR-173) XML
processor written in Java. XML processor means that it handles both
input (= parsing) and output (= writing, serialization)), as well as
supporting tasks such as validation.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{base_name}-%{name}-%{version}

%pom_remove_plugin :nexus-staging-maven-plugin

# we don't care about Java 9 modules (yet)
%pom_remove_plugin :moditect-maven-plugin
%pom_remove_plugin :jacoco-maven-plugin

# replace felix-osgi-core with osgi-core
%pom_change_dep -r :org.osgi.core org.osgi:osgi.core

%{mvn_alias} ":{woodstox-core}" :@1-lgpl :@1-asl :wstx-asl :wstx-lgpl \
    org.codehaus.woodstox:@1 org.codehaus.woodstox:@1-asl \
    org.codehaus.woodstox:@1-lgpl org.codehaus.woodstox:wstx-lgpl \
    org.codehaus.woodstox:wstx-asl

%{mvn_file} : %{name}{,-asl,-lgpl}

%build
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Wed May 25 2022 fstrba@suse.com
- Update to upstream version 6.2.8
  * Fixes:
    + #121: Fix issues outlined by "lgtm.com"'s static analysis
    + #136: 'com.ctc.wstx.evt' is not exported in 'module-info.java'
    + #132: 'copyEventFromReader()' Processing Instruction event bug
    + A few LGTM.com fixes
    + #125: 'ArrayIndexOutOfBoundsException' for UTF-32 encoded data
    + #127: Invalid attributes producing extra null characters
    during DTD validation
    + #123: NPE for content that only has XML declaration and
    unknown encoding
    + #124: ArrayIndexOutOfBoundsException for 4-byte UTF-8
    character at end of CDATA
    + #122: Expected either attr limit (2147483647) >=
    currAttrSize (0) OR >= outBuf.length (96)
* Wed Mar 23 2022 fstrba@suse.com
- Build with java source and target levels 8
* Fri Jun  4 2021 fstrba@suse.com
- Upgrade to upstream version 6.2.3
  * Fixes:
    + #125: 'ArrayIndexOutOfBoundsException' for UTF-32 encoded
    data
    + #127: Invalid attributes producing extra null characters
    during DTD validation
    + #123: NPE for content that only has XML declaration and
    unknown encoding
    + #124: ArrayIndexOutOfBoundsException for 4-byte UTF-8
    character at end of CDATA
    + #122: Expected either attr limit (2147483647) >=
    currAttrSize (0) OR >= outBuf.length (96)
    + #117: Problem with 'Stax2ByteArraySource', encodings other
    than UTF-8
    + #112: Max attributes per element limit only loosely enforced
    + #107: Sub-optimal exception with 'WstxOutputProperties
    .P_OUTPUT_VALIDATE_NAMES'
    + #108: Repairing 'XMLStreamWriter' tries to bind 'xml'
    namespace URI
    + #103: Issue caused by MSV shading
    + #104: 'NullPointerException' in 'DTDValidator
    .validateElementEnd()' for element undefined in DTD
    + #105: W3CSchemaFactory constructor incorrectly references
    relaxng
- Removed patch:
  * 0001-Allow-building-against-OSGi-APIs-newer-than-R4.patch
    + Not needed with this version
* Tue Mar 31 2020 fstrba@suse.com
- Upgrade to upstream version 6.1.1
  * Fixes:
    + Fix for #96 (see below) had an issue leading to
    non-functioning RelaxNG, W3C Schema validation
    + #96: woodstox-core.jar 6.0.2 uses JDK-11 removed internal
    APIs
    + #88: Missing closing quote for attribute values during in
    Validating output mode
    + #93: Stax2 'maxAttributeSize' limit is only vaguely
    respected
    + #97: 'copyEventFromReader()' 'ArrayIndexOutOfBoundsException'
    + #85: OSGi dependency on relaxng should be 'optional'
    + #82: Recycled buffers in XMLStreamWriter are colliding between
    multiple writer instances when used in an Akka stream
    + #78: Shade MSV dependency
    + Add 'module-info.class' for Java 9+ module system
    + #58: Reading comment comments after Root Element closed
    sometimes throws 'NullPointerException'
    + #61: Add support for 'XMLConstants.FEATURE_SECURE_PROCESSING'
    via SAX/Stax factories
    + #74: Infinite loop in BijectiveNsMap#addGeneratedMapping when
    ctxt.getNamespaceURI(prefix) returns an empty String
- Removed patch:
  * 0001-stax2-api.patch
    + Not needed any more with this version
- Added patch:
  * 0001-Allow-building-against-OSGi-APIs-newer-than-R4.patch
    + Migrate build from felix-osgi-core to osgi-core
* Wed Jun  5 2019 jengelh@inai.de
- Ensure neutrality of description.
* Tue Jun  4 2019 fstrba@suse.com
- Initial packaging of woodstox-core 5.2.0
